@@ -8,19 +8,19 @@ use experimental 'smartmatch';
 use Data::Unixish qw(aiduxa);
 use File::Which qw(which);
 use IPC::Cmd qw(run_forked);
-use JSON;
+use JSON::MaybeXS;
 use Module::Load;
 use String::ShellQuote;
 use Test::More 0.96;
 
-our $VERSION = '1.54'; # VERSION
-our $DATE = '2016-03-11'; # DATE
+our $VERSION = '1.55'; # VERSION
+our $DATE = '2016-03-16'; # DATE
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(test_dux_func);
 
-my $json = JSON->new->allow_nonref;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 sub test_dux_func {
     no strict 'refs';
@@ -157,7 +157,7 @@ Test::Data::Unixish - Routines to test Data::Unixish
 
 =head1 VERSION
 
-This document describes version 1.54 of Test::Data::Unixish (from Perl distribution Data-Unixish), released on 2016-03-11.
+This document describes version 1.55 of Test::Data::Unixish (from Perl distribution Data-Unixish), released on 2016-03-16.
 
 =for Pod::Coverage .+
 
@@ -167,7 +167,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
